@@ -1,6 +1,6 @@
 """
 Generated using https://signald.org/protocol.json
-Version: '0.19.1-1-c04b5b70'
+Version: '0.20.0-7-7d9179fd'
 """
 
 from dataclasses import dataclass, field
@@ -536,6 +536,7 @@ class Profilev1:
     color: str = None
     about: str = None
     emoji: str = None
+    contact_name: str = None
     profile_name: str = None
     inbox_position: int = None
     expiration_time: int = None
@@ -980,6 +981,7 @@ class JsonSentTranscriptMessagev1:
     timestamp: int = None
     expirationStartTimestamp: int = None
     message: "JsonDataMessagev1" = None
+    story: "StoryMessagev1" = None
     unidentifiedStatus: dict = None
     isRecipientUpdate: bool = None
 
